@@ -5,7 +5,7 @@ from serverless.service import YamlOrderedDict
 class S3Event(YamlOrderedDict):
     yaml_tag = "s3"
 
-    def __init__(self, bucket, event, rules=None):
+    def __init__(self, bucket, event, rules=None, existing=False):
         super().__init__()
         self.bucket = bucket
         self.event = event
@@ -13,6 +13,9 @@ class S3Event(YamlOrderedDict):
         if rules:
             self.rules = rules
 
+        if existing:
+            self.existing = existing
+
 
 class S3Function(Function):
     yaml_tag = "!S3Function"
@@ -25,6 +28,7 @@ class S3Function(Function):
         bucket,
         event,
         rules=None,
+        existing=None,
         handler=None,
         timeout=None,
         layers=None,
@@ -35,4 +39,4 @@ class S3Function(Function):
         super().__init__(
             service, name, description, handler, timeout, layers, use_dlq=use_dlq, use_async_dlq=use_async_dlq, **kwargs
         )
-        self.trigger(S3Event(bucket, event, rules))
+        self.trigger(S3Event(bucket, event, rules, existing))
