@@ -9,13 +9,13 @@ class DomainManager(Generic):
 
     yaml_tag = "!DomainManagerPlugin"
 
-    def __init__(self, domain="api", api="rest", stage="${sls:stage}", base_path="", create_route_53_record=False, **kwargs):
+    def __init__(
+        self, domain="api", api="rest", stage="${sls:stage}", base_path="", create_route_53_record=False, **kwargs
+    ):
         super().__init__("serverless-domain-manager")
 
         kwargs.setdefault("domainName", f"{api}.{domain}")
-        self[api] = dict(
-            stage=stage, basePath=base_path, createRoute53Record=create_route_53_record, **kwargs
-        )
+        self[api] = dict(stage=stage, basePath=base_path, createRoute53Record=create_route_53_record, **kwargs)
 
     def enable(self, service):
         export = dict(self)
@@ -23,7 +23,5 @@ class DomainManager(Generic):
 
         service.custom.customDomain = export
         param = service.resources.parameter(
-            "RESTApiId",
-            "api-id",
-            {"Fn::GetAtt": ["ApiGatewayRestApi", "RootResourceId"]}
+            "RESTApiId", "api-id", {"Fn::GetAtt": ["ApiGatewayRestApi", "RootResourceId"]}
         )
